<?php
namespace Models;

// Модель для работы с СБП
class Sbp extends \DB\SQL\Mapper{
	public $sbp, $db, $f3, $sets, $method='POST', $messages, $api_data;

	public function __construct($db, $f3) {
		$this->api_data=$f3->get('api_data');
		$this->f3=$f3;
		$this->db=$db;
		parent::__construct($db, 'sbp_settings'); // подключаемся к таблице с настройками
		$this->messages=new \Models\Messages();
		$this->sets=$this->get_sbp();
		if(!$this->sets['active']) return;
		if($this->sets['driver']!='') {
			if(file_exists($this->sets['driver'].'/server.php')) {
				require_once($this->sets['driver'].'/server.php');
				$this->sbp=new Sbp_php($f3, $this->sets);
			}
			else {
				echo 'Ошибка';
			}
		}
	}

	// Узнаем настройки СБП
	function get_sbp() {
		$settings=array();
		$this->reset();
		$this->load(array('rm=?', $this->api_data['rm_id']));
		if($this->dry()) {
			$settings=array(
				'active'=>0,
				'drive'=>'',
				'url'=>''
			);
		}
		else {
			do {
				$settings[$this->name]=$this->value;
			}
			while($this->skip());
		}
		return $settings;
	}

	// Сохраняем настройки СБП
	function save_sbp($post) {
		$sql="INSERT OR REPLACE INTO `sbp_settings` (`name`, `value`, `rm`) VALUES ";
		$val=array();
		foreach ($post as $key => $value) {
			if(!empty($val)) {
				$sql.=", ";
			}
			$sql.="(?, ?, ?)";
			$val[]=$key;
			$val[]=$value;
			$val[]=$this->api_data['rm_id'];
		}
		$res=$this->db->exec($sql, $val);
		if($res!==false) {
			return array(
				'success'=>true,
				'txt'=>'save_successful'
			);
		}
		return array(
			'success'=>false,
			'txt'=>'db_error'
		);
	}

	// Список драйверов
	function get_drivers() {
		$drivers=array();
		$sbp_dir=$this->f3->get('sbp_dir');
		$dirs=scandir($sbp_dir); // Ищем все драйвера
		if($dirs) {
			foreach ($dirs as $d) {
				$folder=$sbp_dir.$d;
				$file=$folder.'/server.config';
				if(is_dir($folder) && file_exists($file)) {
					$config=parse_ini_file($file);
					if($config) {
						$drivers[$folder]=array(
							'title'=>$config['ServerName'],
							'path'=>$folder
						);
					}
				}
			}
		}

		return $drivers;
	}
}
